<?php

namespace TDevAgency\Cms\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use TDevAgency\Cms\Models\BaseModels\AdminUser;
use TDevAgency\Cms\Models\BaseModels\AdminUserRole;

class AddUser extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'cms:add-admin';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Add new admin to DB';

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $user = new AdminUser();
        do {
            $user->name = $this->ask('Name');
            $validator = Validator::make($user->toArray(), [
                'name' => ['required', 'string', 'max:255', 'min:3']
            ]);

            $valid = !$validator->fails();
            if (!$valid) {
                $this->error($validator->errors()->first('name'));
            }
        } while (!$valid);

        do {
            $user->email = $this->ask('E-Mail');
            $validator = Validator::make($user->toArray(), [
                'email' => ['required', 'email', 'max:255']
            ]);

            $valid = !$validator->fails();
            if (!$valid) {
                $this->error($validator->errors()->first('email'));
            }
        } while (!$valid);

        do {
            $password = $this->ask('Password');
            $validator = Validator::make(['password' => $password], [
                'password' => ['required', 'string', 'min:8']
            ]);

            $valid = !$validator->fails();
            if (!$valid) {
                $this->error($validator->errors()->first('password'));
            }
        } while (!$valid);

        $user->password = Hash::make($password);
        $user->is_active = true;
        $user->save();

        $userRole = new AdminUserRole();
        $userRole->admin_user_id = $user->id;

        $userRole->admin_role = 'admin';
        $userRole->save();

        $this->info('Created admin user!');
    }
}
