<?php

namespace TDevAgency\Cms\Providers;

use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Route;
use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Mcamara\LaravelLocalization\Traits\LoadsTranslatedCachedRoutes;
use TDevAgency\Cms\Middleware\LocationMiddleware;
use TDevAgency\Cms\Models\BaseModels\Post;

class RouteServiceProvider extends ServiceProvider
{
    use LoadsTranslatedCachedRoutes;

    /**
     * This namespace is applied to your controller routes.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'TDevAgency\Cms\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @return void
     */
    public function boot()
    {
        //
        parent::boot();

        Route::bind('page', function ($id) {
            return Post::where('post_type', Post::PAGE_TYPE)->findOrFail($id);
        });
        Route::bind('category', function ($id) {
            return Post::where('post_type', Post::CATEGORY_TYPE)->findOrFail($id);
        });
    }

    /**
     * Define the routes for the application.
     *
     * @return void
     */
    public function map()
    {
        $this->mapAdminRoutes();
    }

    /**
     * Define the "web" routes for the application.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapAdminRoutes(): void
    {
        if (Config::get('cms.routes.admin_is_domain')) {
            $host = parse_url(Config::get('app.url'), PHP_URL_HOST);
            Route::middleware(['web', LocationMiddleware::class])->domain(sprintf('%s.%s', Config::get('cms.routes.admin_prefix'), $host))
                ->group(TDEV_AGENCY_CMS_ROOT . 'routes' . DIRECTORY_SEPARATOR . 'admin.php');
        } else {
            Route::middleware(['web', LocationMiddleware::class])->prefix(Config::get('cms.routes.admin_prefix'))
                ->group(TDEV_AGENCY_CMS_ROOT . 'routes' . DIRECTORY_SEPARATOR . 'admin.php');
        }
    }
}
